@@ -5,6 +5,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.gcube.data.analysis.dataminermanagercl.shared.workspace.ItemDescription;
 import org.gcube.portal.clientcontext.client.GCubeClientContext;
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.DataMinerManagerPanel;
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.common.EventBusProvider;
@@ -20,11 +21,11 @@ import org.gcube.portlets.widgets.dataminermanagerwidget.client.type.DataMinerWo
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.util.UtilsGXT3;
 import org.gcube.portlets.widgets.dataminermanagerwidget.shared.Constants;
 import org.gcube.portlets.widgets.dataminermanagerwidget.shared.exception.SessionExpiredServiceException;
-import org.gcube.portlets.widgets.dataminermanagerwidget.shared.workspace.ItemDescription;
+
 import org.gcube.portlets.widgets.workspaceuploader.client.WorkspaceUploadNotification.WorskpaceUploadNotificationListener;
 import org.gcube.portlets.widgets.workspaceuploader.client.uploader.DialogUpload.UPLOAD_TYPE;
 import org.gcube.portlets.widgets.workspaceuploader.client.uploader.dragdrop.MultipleDNDUpload;
-import org.gcube.portlets.widgets.wsexplorer.client.explore.WorkspaceResourcesExplorerPanel;
+import org.gcube.portlets.widgets.wsexplorer.client.explore.WorkspaceResourcesExplorerPanelPaginated;
 import org.gcube.portlets.widgets.wsexplorer.client.notification.WorkspaceExplorerSelectNotification.WorskpaceExplorerSelectNotificationListener;
 import org.gcube.portlets.widgets.wsexplorer.client.view.grid.ItemsTable.DISPLAY_FIELD;
 import org.gcube.portlets.widgets.wsexplorer.shared.FilterCriteria;
@@ -50,20 +51,21 @@ import com.sencha.gxt.widget.core.client.toolbar.ToolBar;
 
 /**
  * 
- * @author Giancarlo Panichi email: <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  *
  */
 public class ComputationsExecutedPanel extends FramedPanel {
 
 	private Item selectedItem;
 	private MultipleDNDUpload dnd;
-	private WorkspaceResourcesExplorerPanel wsResourcesExplorerPanel;
+	private WorkspaceResourcesExplorerPanelPaginated wsResourcesExplorerPanel;
+	// private WorkspaceResourcesExplorerPanel wsResourcesExplorerPanel;
 	private TextButton btnShow;
 	private TextButton btnDownload;
 	private TextButton btnDelete;
 	private TextButton btnRefresh;
-	//private TextButton btnResubmit;
+	// private TextButton btnResubmit;
 	private TextButton btnCancel;
 	private VerticalLayoutContainer v;
 
@@ -92,15 +94,14 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 	private void bindToEvents() {
 
-		EventBusProvider.INSTANCE.addHandler(UIStateEvent.TYPE,
-				new UIStateEvent.UIStateEventHandler() {
+		EventBusProvider.INSTANCE.addHandler(UIStateEvent.TYPE, new UIStateEvent.UIStateEventHandler() {
 
-					@Override
-					public void onChange(UIStateEvent event) {
-						manageStateEvents(event);
+			@Override
+			public void onChange(UIStateEvent event) {
+				manageStateEvents(event);
 
-					}
-				});
+			}
+		});
 
 		EventBusProvider.INSTANCE.addHandler(DataMinerWorkAreaEvent.TYPE,
 				new DataMinerWorkAreaEvent.DataMinerWorkAreaEventHandler() {
@@ -113,19 +114,16 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 				});
 
-		EventBusProvider.INSTANCE
-				.addHandler(
-						RefreshDataMinerWorkAreaEvent.TYPE,
-						new RefreshDataMinerWorkAreaEvent.RefreshDataMinerWorkAreaEventHandler() {
+		EventBusProvider.INSTANCE.addHandler(RefreshDataMinerWorkAreaEvent.TYPE,
+				new RefreshDataMinerWorkAreaEvent.RefreshDataMinerWorkAreaEventHandler() {
 
-							@Override
-							public void onRefresh(
-									RefreshDataMinerWorkAreaEvent event) {
-								manageRefreshDataMinerWorkAreaEvents(event);
+					@Override
+					public void onRefresh(RefreshDataMinerWorkAreaEvent event) {
+						manageRefreshDataMinerWorkAreaEvents(event);
 
-							}
+					}
 
-						});
+				});
 
 	}
 
@@ -150,8 +148,7 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 	private void manageDataMinerWorkAreaEvents(DataMinerWorkAreaEvent event) {
 
-		Log.debug("ComputationsExecutedPanel recieved DataMinerWorkAreaEvent: "
-				+ event);
+		Log.debug("ComputationsExecutedPanel recieved DataMinerWorkAreaEvent: " + event);
 		if (event == null) {
 			Log.error("DataMinerWorkAreaEvent null");
 			return;
@@ -181,10 +178,8 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 	}
 
-	private void manageRefreshDataMinerWorkAreaEvents(
-			RefreshDataMinerWorkAreaEvent event) {
-		Log.debug("ComputationsExecutedPanel recieved RefreshDataMinerWorkAreaEvent: "
-				+ event);
+	private void manageRefreshDataMinerWorkAreaEvents(RefreshDataMinerWorkAreaEvent event) {
+		Log.debug("ComputationsExecutedPanel recieved RefreshDataMinerWorkAreaEvent: " + event);
 		if (event == null) {
 			Log.error("RefreshDataMinerWorkAreaEvent null");
 			return;
@@ -204,17 +199,14 @@ public class ComputationsExecutedPanel extends FramedPanel {
 	}
 
 	private void create(DataMinerWorkAreaEvent event) {
+		Log.debug("Create ComputationsExecutedPanel");
 		try {
 
-			if (event == null
-					|| event.getDataMinerWorkArea() == null
+			if (event == null || event.getDataMinerWorkArea() == null
 					|| event.getDataMinerWorkArea().getComputations() == null
-					|| event.getDataMinerWorkArea().getComputations()
-							.getFolder() == null
-					|| event.getDataMinerWorkArea().getComputations()
-							.getFolder().getId() == null
-					|| event.getDataMinerWorkArea().getComputations()
-							.getFolder().getId().isEmpty()) {
+					|| event.getDataMinerWorkArea().getComputations().getFolder() == null
+					|| event.getDataMinerWorkArea().getComputations().getFolder().getId() == null
+					|| event.getDataMinerWorkArea().getComputations().getFolder().getId().isEmpty()) {
 				if (v != null) {
 					remove(v);
 					forceLayout();
@@ -224,18 +216,27 @@ public class ComputationsExecutedPanel extends FramedPanel {
 			}
 
 			List<String> showProperties = new ArrayList<String>();
-			for (ComputationsPropertiesType computationsProperties : ComputationsPropertiesType
-					.values()) {
+			for (ComputationsPropertiesType computationsProperties : ComputationsPropertiesType.values()) {
 				showProperties.add(computationsProperties.getLabel());
 			}
 			FilterCriteria filterCriteria = new FilterCriteria();
 			Map<String, String> map = new HashMap<String, String>();
 			filterCriteria.setRequiredProperties(map);
 
-			wsResourcesExplorerPanel = new WorkspaceResourcesExplorerPanel(
-					event.getDataMinerWorkArea().getComputations().getFolder()
-							.getId(), false, showProperties, filterCriteria,
-					true, DISPLAY_FIELD.CREATION_DATE);
+			/*
+			 * wsResourcesExplorerPanel = new WorkspaceResourcesExplorerPanel(
+			 * event.getDataMinerWorkArea().getComputations().getFolder()
+			 * .getId(), false, showProperties, filterCriteria, true,
+			 * DISPLAY_FIELD.CREATION_DATE);
+			 */
+			Log.debug("Create wsResourcesExplorerPanel for Computations: ["
+					+ event.getDataMinerWorkArea().getComputations().getFolder().getId() + ", false, " + showProperties
+					+ ", " + filterCriteria + ", true, " + DISPLAY_FIELD.CREATION_DATE + "]");
+
+			wsResourcesExplorerPanel = new WorkspaceResourcesExplorerPanelPaginated(
+					event.getDataMinerWorkArea().getComputations().getFolder().getId(), false, showProperties,
+					filterCriteria, true, DISPLAY_FIELD.CREATION_DATE);
+			Log.debug("Created wsResourcesExplorerPanel");
 			WorskpaceExplorerSelectNotificationListener wsResourceExplorerListener = new WorskpaceExplorerSelectNotificationListener() {
 				@Override
 				public void onSelectedItem(Item item) {
@@ -260,10 +261,10 @@ public class ComputationsExecutedPanel extends FramedPanel {
 					selectedItem = null;
 				}
 			};
-
-			wsResourcesExplorerPanel
-					.addWorkspaceExplorerSelectNotificationListener(wsResourceExplorerListener);
-			wsResourcesExplorerPanel.ensureDebugId("wsResourceExplorerPanel");
+			Log.debug("Add WorkspaceExplorerSelectNotificationListener");
+			wsResourcesExplorerPanel.addWorkspaceExplorerSelectNotificationListener(wsResourceExplorerListener);
+			wsResourcesExplorerPanel.ensureDebugId("wsResourceExplorerPanelComputaions");
+			Log.debug("Set Height to internal SCROLL 300");
 			wsResourcesExplorerPanel.setHeightToInternalScroll(300);
 
 			/*
@@ -273,18 +274,17 @@ public class ComputationsExecutedPanel extends FramedPanel {
 			 * vResourcesExplorerContainer.add(wsResourcesExplorerPanel, new
 			 * VerticalLayoutData(1, -1, new Margins(0)));
 			 */
+			Log.debug("Define DND for Computations");
 			// DND
 
 			dnd = new MultipleDNDUpload();
-			dnd.setParameters(event.getDataMinerWorkArea().getComputations()
-					.getFolder().getId(), UPLOAD_TYPE.File);
+			dnd.setParameters(event.getDataMinerWorkArea().getComputations().getFolder().getId(), UPLOAD_TYPE.File);
 			dnd.addUniqueContainer(wsResourcesExplorerPanel);
 			WorskpaceUploadNotificationListener workspaceUploaderListener = new WorskpaceUploadNotificationListener() {
 
 				@Override
 				public void onUploadCompleted(String parentId, String itemId) {
-					Log.debug("Upload completed: [parentID: " + parentId
-							+ ", itemId: " + itemId + "]");
+					Log.debug("Upload completed: [parentID: " + parentId + ", itemId: " + itemId + "]");
 					wsResourcesExplorerPanel.refreshRootFolderView();
 					forceLayout();
 
@@ -292,22 +292,18 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 				@Override
 				public void onUploadAborted(String parentId, String itemId) {
-					Log.debug("Upload Aborted: [parentID: " + parentId
-							+ ", itemId: " + itemId + "]");
+					Log.debug("Upload Aborted: [parentID: " + parentId + ", itemId: " + itemId + "]");
 				}
 
 				@Override
-				public void onError(String parentId, String itemId,
-						Throwable throwable) {
-					Log.debug("Upload Error: [parentID: " + parentId
-							+ ", itemId: " + itemId + "]");
+				public void onError(String parentId, String itemId, Throwable throwable) {
+					Log.debug("Upload Error: [parentID: " + parentId + ", itemId: " + itemId + "]");
 					throwable.printStackTrace();
 				}
 
 				@Override
 				public void onOverwriteCompleted(String parentId, String itemId) {
-					Log.debug("Upload Override Completed: [parentID: "
-							+ parentId + ", itemId: " + itemId + "]");
+					Log.debug("Upload Override Completed: [parentID: " + parentId + ", itemId: " + itemId + "]");
 					wsResourcesExplorerPanel.refreshRootFolderView();
 					forceLayout();
 				}
@@ -372,19 +368,19 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 			});
 
-			/*btnResubmit = new TextButton("Resubmit");
-			btnResubmit.setIcon(DataMinerManagerPanel.resources.resubmit());
-			btnResubmit.setScale(ButtonScale.SMALL);
-			btnResubmit.setIconAlign(IconAlign.LEFT);
-			btnResubmit.setToolTip("Resubmit");
-			btnResubmit.addSelectHandler(new SelectHandler() {
-
-				@Override
-				public void onSelect(SelectEvent event) {
-					resubmitComputation();
-				}
-
-			});*/
+			/*
+			 * btnResubmit = new TextButton("Resubmit");
+			 * btnResubmit.setIcon(DataMinerManagerPanel.resources.resubmit());
+			 * btnResubmit.setScale(ButtonScale.SMALL);
+			 * btnResubmit.setIconAlign(IconAlign.LEFT);
+			 * btnResubmit.setToolTip("Resubmit");
+			 * btnResubmit.addSelectHandler(new SelectHandler() {
+			 * 
+			 * @Override public void onSelect(SelectEvent event) {
+			 * resubmitComputation(); }
+			 * 
+			 * });
+			 */
 
 			btnCancel = new TextButton("Cancel");
 			btnCancel.setIcon(DataMinerManagerPanel.resources.cancelCircle());
@@ -405,7 +401,7 @@ public class ComputationsExecutedPanel extends FramedPanel {
 			toolBar.add(btnDownload, new BoxLayoutData(new Margins(0)));
 			toolBar.add(btnDelete, new BoxLayoutData(new Margins(0)));
 			toolBar.add(btnRefresh, new BoxLayoutData(new Margins(0)));
-			//toolBar.add(btnResubmit, new BoxLayoutData(new Margins(0)));
+			// toolBar.add(btnResubmit, new BoxLayoutData(new Margins(0)));
 			toolBar.add(btnCancel, new BoxLayoutData(new Margins(0)));
 
 			v = new VerticalLayoutContainer();
@@ -418,11 +414,9 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 				@Override
 				public void onResize(ResizeEvent event) {
-					int scrollBarHeight = event.getHeight()
-							- toolBar.getElement().getHeight(false);
+					int scrollBarHeight = event.getHeight() - toolBar.getElement().getHeight(false);
 					Log.debug("ScrollBarHeight: " + scrollBarHeight);
-					wsResourcesExplorerPanel
-							.setHeightToInternalScroll(scrollBarHeight);
+					wsResourcesExplorerPanel.setHeightToInternalScroll(scrollBarHeight);
 					forceLayout();
 
 				}
@@ -437,7 +431,13 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 	private void refreshWSResourceExplorerPanel() {
 		if (wsResourcesExplorerPanel != null) {
-			wsResourcesExplorerPanel.refreshRootFolderView();
+			try {
+				// wsResourcesExplorerPanel.hardRefresh();
+				wsResourcesExplorerPanel.refreshRootFolderView();
+			} catch (Exception e) {
+				Log.error("Error retrieving data: " + e.getLocalizedMessage());
+
+			}
 		}
 	}
 
@@ -458,12 +458,10 @@ public class ComputationsExecutedPanel extends FramedPanel {
 	}
 
 	private void deleteItem(SelectEvent event) {
-		ItemDescription itemDescription = new ItemDescription(
-				selectedItem.getId(), selectedItem.getName(),
-				selectedItem.getOwner(), selectedItem.getPath(), selectedItem
-						.getType().name());
-		DeleteItemRequestEvent deleteItemEvent = new DeleteItemRequestEvent(
-				DataMinerWorkAreaElementType.Computations, itemDescription);
+		ItemDescription itemDescription = new ItemDescription(selectedItem.getId(), selectedItem.getName(),
+				selectedItem.getOwner(), selectedItem.getPath(), selectedItem.getType().name());
+		DeleteItemRequestEvent deleteItemEvent = new DeleteItemRequestEvent(DataMinerWorkAreaElementType.Computations,
+				itemDescription);
 		EventBusProvider.INSTANCE.fireEvent(deleteItemEvent);
 		Log.debug("Fired: " + deleteItemEvent);
 	}
@@ -471,13 +469,10 @@ public class ComputationsExecutedPanel extends FramedPanel {
 	private void showComputation() {
 		if (selectedItem != null) {
 
-			final ItemDescription itemDescription = new ItemDescription(
-					selectedItem.getId(), selectedItem.getName(),
-					selectedItem.getOwner(), selectedItem.getPath(),
-					selectedItem.getType().name());
+			final ItemDescription itemDescription = new ItemDescription(selectedItem.getId(), selectedItem.getName(),
+					selectedItem.getOwner(), selectedItem.getPath(), selectedItem.getType().name());
 
-			ComputationDataRequestEvent event = new ComputationDataRequestEvent(
-					itemDescription);
+			ComputationDataRequestEvent event = new ComputationDataRequestEvent(itemDescription);
 			EventBusProvider.INSTANCE.fireEvent(event);
 
 		} else {
@@ -491,53 +486,41 @@ public class ComputationsExecutedPanel extends FramedPanel {
 			if (selectedItem.isFolder()) {
 				StringBuilder actionUrl = new StringBuilder();
 				actionUrl.append(GWT.getModuleBaseURL());
-				actionUrl
-						.append(Constants.DOWNLOAD_FOLDER_SERVLET
-								+ "?"
-								+ Constants.DOWNLOAD_FOLDER_SERVLET_ITEM_ID_PARAMETER
-								+ "="
-								+ selectedItem.getId()
-								+ "&"
-								+ Constants.DOWNLOAD_FOLDER_SERVLET_FOLDER_NAME_PARAMETER
-								+ "=" + selectedItem.getName() + "&"
-								+ Constants.CURR_GROUP_ID + "="
-								+ GCubeClientContext.getCurrentContextId());
+				actionUrl.append(Constants.DOWNLOAD_FOLDER_SERVLET + "?"
+						+ Constants.DOWNLOAD_FOLDER_SERVLET_ITEM_ID_PARAMETER + "=" + selectedItem.getId() + "&"
+						+ Constants.DOWNLOAD_FOLDER_SERVLET_FOLDER_NAME_PARAMETER + "=" + selectedItem.getName() + "&"
+						+ Constants.CURR_GROUP_ID + "=" + GCubeClientContext.getCurrentContextId());
 
 				Log.debug("Retrieved link: " + actionUrl);
 				Window.open(actionUrl.toString(), selectedItem.getName(), "");
 
 			} else {
 
-				final ItemDescription itemDescription = new ItemDescription(
-						selectedItem.getId(), selectedItem.getName(),
-						selectedItem.getOwner(), selectedItem.getPath(),
+				final ItemDescription itemDescription = new ItemDescription(selectedItem.getId(),
+						selectedItem.getName(), selectedItem.getOwner(), selectedItem.getPath(),
 						selectedItem.getType().name());
 
-				DataMinerPortletServiceAsync.INSTANCE.getPublicLink(
-						itemDescription, new AsyncCallback<String>() {
+				DataMinerPortletServiceAsync.INSTANCE.getPublicLink(itemDescription, new AsyncCallback<String>() {
 
-							@Override
-							public void onFailure(Throwable caught) {
-								if (caught instanceof SessionExpiredServiceException) {
-									EventBusProvider.INSTANCE
-											.fireEvent(new SessionExpiredEvent());
-								} else {
-									Log.error("Error open file: "
-											+ caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error",
-											caught.getLocalizedMessage());
-								}
-								caught.printStackTrace();
+					@Override
+					public void onFailure(Throwable caught) {
+						if (caught instanceof SessionExpiredServiceException) {
+							EventBusProvider.INSTANCE.fireEvent(new SessionExpiredEvent());
+						} else {
+							Log.error("Error open file: " + caught.getLocalizedMessage());
+							UtilsGXT3.alert("Error", caught.getLocalizedMessage());
+						}
+						caught.printStackTrace();
 
-							}
+					}
 
-							@Override
-							public void onSuccess(String link) {
-								Log.debug("Retrieved link: " + link);
-								Window.open(link, itemDescription.getName(), "");
-							}
+					@Override
+					public void onSuccess(String link) {
+						Log.debug("Retrieved link: " + link);
+						Window.open(link, itemDescription.getName(), "");
+					}
 
-						});
+				});
 			}
 		} else {
 			UtilsGXT3.info("Attention", "Select a file!");
@@ -547,10 +530,8 @@ public class ComputationsExecutedPanel extends FramedPanel {
 
 	private void cancelComputation() {
 		if (selectedItem != null) {
-			ItemDescription itemDescription = new ItemDescription(
-					selectedItem.getId(), selectedItem.getName(),
-					selectedItem.getOwner(), selectedItem.getPath(),
-					selectedItem.getType().name());
+			ItemDescription itemDescription = new ItemDescription(selectedItem.getId(), selectedItem.getName(),
+					selectedItem.getOwner(), selectedItem.getPath(), selectedItem.getType().name());
 			CancelExecutionFromComputationsRequestEvent cancelComputationEvent = new CancelExecutionFromComputationsRequestEvent(
 					itemDescription);
 			EventBusProvider.INSTANCE.fireEvent(cancelComputationEvent);
@@ -560,20 +541,18 @@ public class ComputationsExecutedPanel extends FramedPanel {
 		}
 	}
 
-	/*private void resubmitComputation() {
-		if (selectedItem != null) {
-			ItemDescription itemDescription = new ItemDescription(
-					selectedItem.getId(), selectedItem.getName(),
-					selectedItem.getOwner(), selectedItem.getPath(),
-					selectedItem.getType().name());
-			ResubmitComputationExecutionRequestEvent resubmitComputationEvent = new ResubmitComputationExecutionRequestEvent(
-					itemDescription);
-			EventBusProvider.INSTANCE.fireEvent(resubmitComputationEvent);
-			Log.debug("Fired: " + resubmitComputationEvent);
-		} else {
-			UtilsGXT3.info("Attention", "Select a computation!");
-		}
-
-	}*/
+	/*
+	 * private void resubmitComputation() { if (selectedItem != null) {
+	 * ItemDescription itemDescription = new ItemDescription(
+	 * selectedItem.getId(), selectedItem.getName(), selectedItem.getOwner(),
+	 * selectedItem.getPath(), selectedItem.getType().name());
+	 * ResubmitComputationExecutionRequestEvent resubmitComputationEvent = new
+	 * ResubmitComputationExecutionRequestEvent( itemDescription);
+	 * EventBusProvider.INSTANCE.fireEvent(resubmitComputationEvent);
+	 * Log.debug("Fired: " + resubmitComputationEvent); } else {
+	 * UtilsGXT3.info("Attention", "Select a computation!"); }
+	 * 
+	 * }
+	 */
 
 }
